TnRouter class
The TnRouter Singleton, this holds the navigation flow logic
TnRouter()..setRoutes(tnRoutesList)
Constructors
- TnRouter()
-
factory
Properties
- canPop → bool
-
Whether the stack can be pop or not
no setter
- count → int
-
int to get the amount of routes in the stack
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- isOpened → bool
-
Whether the bottom navigator is opened to avoid overlap
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
stream
→ Stream<
List< Widget> > -
stream to listen the navigation stack changes
no setter
Methods
-
clear(
) → void - Method to clear navigation stack
-
dispose(
) → void - Method to dispose streams and reset opened variable
-
go(
String path, {Map< String, dynamic> ? params, required BuildContext context}) → void - Method to clear stack and nav to path
-
initialize(
) → void - Method to initialize the bottom navigator
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
pop(
) → void - Method to nav backward in the navigation stack
-
push(
String path, {Map< String, dynamic> ? params, required BuildContext context}) → void - Method to add new route in the stack
-
setRoutes(
List< TnBottomSheetRoute> routes) → void - Method to initialize the routes
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited